﻿using System;
using System.Configuration;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace CustomZoomLevelSet {
    public partial class TestForm : System.Web.UI.Page {
        protected void Page_Load(object sender, EventArgs e) {
            if (!Page.IsPostBack) {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
                Map1.CurrentExtent = new RectangleShape(-131.22, 55.05, -54.03, 16.91);
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                //WorldMapKitWmsWebOverlay worldMapKitOverlay = new WorldMapKitWmsWebOverlay();
                //Map1.CustomOverlays.Add(worldMapKitOverlay);

                var vstyle = new ValueStyle();
                vstyle.ColumnName = "STATE_ID";
                vstyle.ValueItems.Add(new ValueItem("1", AreaStyles.Country2));
                vstyle.ValueItems.Add(new ValueItem("2", AreaStyles.Antarctica1));
                vstyle.ValueItems.Add(new ValueItem("3", AreaStyles.Country1));
                vstyle.ValueItems.Add(new ValueItem("40", AreaStyles.Water2));
                vstyle.ValueItems.Add(new ValueItem("50", AreaStyles.Wildlife1));

                ShapeFileFeatureLayer USLayer = new ShapeFileFeatureLayer(MapPath("~/App_Data/states.shp"));
                //Hide the first two zoom levels
                USLayer.ZoomLevelSet.CustomZoomLevels.Add(GetAreaZoomLevel(30000000, new AreaStyle()));
                USLayer.ZoomLevelSet.CustomZoomLevels.Add(GetAreaZoomLevelForValueStyle(7500000, vstyle));
                USLayer.ZoomLevelSet.CustomZoomLevels.Add(GetAreaZoomLevel(3000000, AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.LightBlue, GeoColor.SimpleColors.PaleGreen)));

                //Hide the sixth zoom level.
                USLayer.ZoomLevelSet.CustomZoomLevels.Add(GetAreaZoomLevel(1500000, new AreaStyle()));
                USLayer.ZoomLevelSet.CustomZoomLevels.Add(GetAreaZoomLevel(50000, AreaStyles.County1));

                LayerOverlay staticOverlay = new LayerOverlay();
                staticOverlay.IsBaseOverlay = false;
                staticOverlay.Layers.Add(USLayer);
                Map1.CustomOverlays.Add(staticOverlay);

                Map1.SyncClientZoomLevels(GetCustomZoomLevelSet());
            }
        }

        private ZoomLevelSet GetCustomZoomLevelSet() {
            ZoomLevelSet zoomLevelSet = new ZoomLevelSet();
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(62500000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(30000000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(15000000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(7500000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(3000000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(1500000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(700000));
            return zoomLevelSet;
        }

        private ZoomLevel GetAreaZoomLevel(double scale, AreaStyle areaStyle) {
            ZoomLevel zoomLevel = new ZoomLevel(scale);
            zoomLevel.DefaultAreaStyle = areaStyle;
            return zoomLevel;
        }

        private ZoomLevel GetAreaZoomLevelForValueStyle(double scale, ValueStyle valueStyle) {
            ZoomLevel zoomLevel = new ZoomLevel(scale);
            zoomLevel.CustomStyles.Add(valueStyle);
            return zoomLevel;
        }
    }
}
